# -*- encoding: utf-8 -*-

from django import forms
from django.forms.widgets import Select
from models import NOM_CHAMPS_ETAT, TEXTE_CHAMPS_ETAT, HELP_CHAMPS_ETAT

def form_initialiser_etats(form, request, instance=None):
    """
    Modifier le champs 'etat' à travers le form, pour lui fournir la liste
    des états en fonction du contexte.
    """
    if instance:
        # ModelForm
        fields = getattr(form, 'fields', None)
        # AdminForm
        if not fields:
            fields = getattr(form, 'base_fields', None)
        choices = instance.get_etats_disponibles(request)
        fields[NOM_CHAMPS_ETAT].choices = choices
        fields[NOM_CHAMPS_ETAT].widget = Select(choices=choices)
    else:
        etat_initial = form.Meta.model.etat_initial
        libelle_etat_initial = form.Meta.model.etats[etat_initial]
        form.base_fields[NOM_CHAMPS_ETAT].initial = etat_initial
        choices = [(etat_initial, libelle_etat_initial), ]

        form.base_fields[NOM_CHAMPS_ETAT].choices = choices
        form.base_fields[NOM_CHAMPS_ETAT].widget = Select(choices=choices)


class WorkflowFormMixin(forms.ModelForm):
    """
    Mixin pour crééer un formulaire avec l'état dans le frontend.
    """
    etat = forms.ChoiceField(label=TEXTE_CHAMPS_ETAT, help_text=HELP_CHAMPS_ETAT)

    def __init__(self, *args, **kwargs):
        instance = kwargs['instance']
        if kwargs.has_key('request'):
            request = kwargs['request']
            del kwargs['request']
        super(WorkflowFormMixin, self).__init__(**kwargs)
        form_initialiser_etats(self, request=request, instance=instance)

